@@ -86,7 +86,7 @@
 #define KCMUTILSCORE_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KCMUTILSCORE_NO_DEPRECATED
-#  define KCMUTILSCORE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55e00
+#  define KCMUTILSCORE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55f00
 #endif
 #ifdef KCMUTILSCORE_NO_DEPRECATED_WARNINGS
 #  define KCMUTILSCORE_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KCMUTILSCORE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KCMUTILSCORE_DEPRECATED_WARNINGS_SINCE KCMUTILSCORE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KCMUTILSCORE_DEPRECATED_WARNINGS_SINCE 0x55e00
+#    define KCMUTILSCORE_DEPRECATED_WARNINGS_SINCE 0x55f00
 #  endif
 #endif
 
@@ -164,7 +164,7 @@
 #define KCMUTILSCORE_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KCMUTILSCORE_NO_DEPRECATED
-#  define KCMUTILSCORE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55e00
+#  define KCMUTILSCORE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55f00
 #endif
 #ifdef KCMUTILSCORE_NO_DEPRECATED_WARNINGS
 #  define KCMUTILSCORE_DEPRECATED_WARNINGS_SINCE 0
@@ -174,7 +174,7 @@
 #  ifdef KCMUTILSCORE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KCMUTILSCORE_DEPRECATED_WARNINGS_SINCE KCMUTILSCORE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KCMUTILSCORE_DEPRECATED_WARNINGS_SINCE 0x55e00
+#    define KCMUTILSCORE_DEPRECATED_WARNINGS_SINCE 0x55f00
 #  endif
 #endif
 
